@@ -36,14 +36,12 @@ extern void msg_logger_control(int,...);
 #define MSG_LOGGER_CTL_FALLBACK_FN	2
 
 /* Safer API: type-checked arguments, external use. */
-#define CA_MSG_LOGGER_CTL_END              MSG_LOGGER_CTL_END
-#define CA_MSG_LOGGER_CTL_FALLBACK_ONLY(v) \
-	MSG_LOGGER_CTL_FALLBACK_ONLY,  CHECK_VAL(MSG_LOGGER_CTL, int, (v))
+#define CA_MSG_LOGGER_CTL_END		MSG_LOGGER_CTL_END
+#define CA_MSG_LOGGER_CTL_FALLBACK_ONLY	MSG_LOGGER_CTL_FALLBACK_ONLY
 #define CA_MSG_LOGGER_CTL_FALLBACK_FN(v) \
 	MSG_LOGGER_CTL_FALLBACK_FN, CHECK_VAL(MSG_LOGGER_CTL, \
 		MSG_LOGGER_FALLBACK_FN, (v))
 
-CHECK_VAL_HELPER_DCL(MSG_LOGGER_CTL, int);
 CHECK_VAL_HELPER_DCL(MSG_LOGGER_CTL, MSG_LOGGER_FALLBACK_FN);
 
 /* LICENSE
